@@ -18,8 +18,8 @@
 ;; URL:      https://github.com/meedstrom/dired-du-duc
 ;; Created:  2025-12-03
 ;; Keywords: files
-;; Package-Version: 0.1.3
-;; Package-Revision: 0.1.3-0-gf7f1a915e5a3
+;; Package-Version: 20251223.1946
+;; Package-Revision: 8b72d0a3c423
 ;; Package-Requires: ((emacs "29.1") (dired-du "0.5.2"))
 
 ;;; Commentary:
@@ -60,8 +60,6 @@
   :link '(url-link "https://github.com/zevv/duc")
   :link '(url-link "https://duc.zevv.nl/"))
 
-(defvar dired-du-duc-debug nil)
-
 
 ;;;; Local mode
 
@@ -179,11 +177,10 @@ and arrange to run `dired-du-duc-after-re-index-hook' afterwards."
                         when (file-readable-p dir)
                         collect dir))
     (when dirs
-      (when dired-du-duc-debug
-        (cl-assert
-         (not (cl-intersection dirs
-                               (seq-mapcat #'cdr dired-du-duc--process-dirs)
-                               :test #'equal))))
+      (cl-assert
+       (not (cl-intersection dirs
+                             (seq-mapcat #'cdr dired-du-duc--process-dirs)
+                             :test #'equal)))
       (let ((proc (apply #'start-process
                          "duc" " *duc*"
                          "duc" "index" "-v" dirs)))
@@ -212,8 +209,7 @@ fewer directories than `dired-du-duc-before-index-functions' does.")
                    when (and (member dir newly-indexed)
                              (buffer-live-p buf))
                    do (with-current-buffer buf
-                        (when (and (derived-mode-p 'dired-mode)
-                                   (file-exists-p default-directory))
+                        (when (derived-mode-p 'dired-mode)
                           (if (dired-du-duc-indexed-p)
                               (let ((dired-du-duc--inhibit-index t))
                                 (setq-local dired-du-duc-using-duc t)
